==> apache-karaf-4.2.16.zip: apache-karaf-4.2.16/examples/karaf-bundle-example/karaf-bundle-example-provider/src/main/java/org/apache/karaf/examples/bundle/provider/internal/Activator.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.karaf.examples.bundle.provider.internal;

import org.apache.karaf.examples.bundle.common.BookingService;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceRegistration;

public class Activator implements BundleActivator {

    private ServiceRegistration serviceRegistration;

    @Override
    public void start(BundleContext bundleContext) throws Exception {
        // create a booking service impl instance
        BookingServiceImpl bookingService = new BookingServiceImpl();
        // registering the booking service in the service registry
        serviceRegistration = bundleContext.registerService(BookingService.class, bookingService, null);
    }

    @Override
    public void stop(BundleContext bundleContext) throws Exception {
        if (serviceRegistration != null) {
            // remove the service from the service registry
            serviceRegistration.unregister();
        }
    }
}

==> apache-karaf-4.4.8.zip: apache-karaf-4.4.8/examples/karaf-bundle-example/karaf-bundle-example-provider/src/main/java/org/apache/karaf/examples/bundle/provider/internal/Activator.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.karaf.examples.bundle.provider.internal;

import org.apache.karaf.examples.bundle.common.BookingService;
import org.osgi.annotation.bundle.Header;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.Constants;
import org.osgi.framework.ServiceRegistration;

@Header(name = Constants.BUNDLE_ACTIVATOR, value = "${@class}")
public class Activator implements BundleActivator {

    private ServiceRegistration serviceRegistration;

    @Override
    public void start(BundleContext bundleContext) throws Exception {
        // create a booking service impl instance
        BookingServiceImpl bookingService = new BookingServiceImpl();
        // registering the booking service in the service registry
        serviceRegistration = bundleContext.registerService(BookingService.class, bookingService, null);
    }

    @Override
    public void stop(BundleContext bundleContext) throws Exception {
        if (serviceRegistration != null) {
            // remove the service from the service registry
            serviceRegistration.unregister();
        }
    }
}
